==> firefox-58.0b13.source.tar.xz: firefox-58.0b13/browser/extensions/activity-stream/prerendered/locales/tl/activity-stream-strings.js <==
// Note - this is a generated file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Bagong Tab",
  "default_label_loading": "Pagkarga…",
  "header_top_sites": "Tuktok na mga Site",
  "header_stories": "Nangunguna na mga Kwento",
  "header_highlights": "Naka-highlight",
  "header_visit_again": "Bisitahin Muli",
  "header_bookmarks": "Kamakailang mga Bookmark",
  "header_recommended_by": "Inirekomenda ni {provider}",
  "header_bookmarks_placeholder": "Wala kang anumang mga bookmark.",
  "header_stories_from": "mula sa",
  "type_label_visited": "Binisita",
  "type_label_bookmarked": "Bookmarked",
  "type_label_synced": "Naka-sync mula sa ibang kagamitan",
  "type_label_recommended": "Nagte-trend",
  "type_label_open": "Bukas",
  "type_label_topic": "Topiko",
  "type_label_now": "Ngayon",
  "menu_action_bookmark": "Bookmark",
  "menu_action_remove_bookmark": "Alisin ang Bookmark",
  "menu_action_copy_address": "Kopyahin ang Address",
  "menu_action_email_link": "Email Link…",
  "menu_action_open_new_window": "Buksan sa isang Bagong Window",
  "menu_action_open_private_window": "Buksan sa isang Pribadong Bago na Window",
  "menu_action_dismiss": "Paalisin",
  "menu_action_delete": "Tanggalin mula History",
  "menu_action_pin": "I-pin",
  "menu_action_unpin": "I-unpin",
  "confirm_history_delete_p1": "Sigurado ka bang gusto mong tanggalin ang bawat pagkakataon ng pahinang ito mula sa iyong kasaysayan?",
  "confirm_history_delete_notice_p2": "Ang aksyon na ito ay hindi na mababawi.",
  "menu_action_save_to_pocket": "I-save sa Pocket",
  "search_for_something_with": "Maghanap ng mga {search_term} na may:",
  "search_button": "Hanapin",
  "search_header": "{search_engine_name} Hanapin",
  "search_web_placeholder": "Hanapin sa Web",
  "search_settings": "Baguhin ang mga Setting ng Paghahanap",
  "section_info_option": "Impormasyon",
  "section_info_send_feedback": "Magbigay ng Feedback",
  "section_info_privacy_notice": "Abiso sa Privacy",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "welcome_title": "Maligayang pagdating sa bagong tab",
  "welcome_body": "Firefox ay gagamit ng puwang upang ipakita ang iyong mga pinaka-kaugnay na bookmark, artikulo, video, at mga pahina ng kamakailan na iyong binisita, kaya maaari kang bumalik sa mga ito ng madali.",
  "welcome_label": "Ang pagkilala sa iyong Highlights",
  "time_label_less_than_minute": "<1m",
  "time_label_minute": "{number}m",
  "time_label_hour": "{number}h",
  "time_label_day": "{number}d",
  "settings_pane_button_label": "I-customize ang iyong pahina ng Bagong Tab",
  "settings_pane_header": "Bagong Kagustuhan na Tab",
  "settings_pane_body2": "Piliin kung ano ang gusto mong makita sa pahinang ito.",
  "settings_pane_search_header": "Paghahanap",
  "settings_pane_search_body": "Hanapin sa Web mula sa iyong bagong tab.",
  "settings_pane_topsites_header": "Tuktok na mga Site",
  "settings_pane_topsites_body": "Ma-access ang mga website na karamihang binibisita.",
  "settings_pane_topsites_options_showmore": "Ipakita ang dalawang mga hanay",
  "settings_pane_bookmarks_header": "Kamakailang mga Bookmark",
  "settings_pane_bookmarks_body": "Ang iyong mga bagong gawang bookmark ay nsa isang madaling gamiting lokasyon.",
  "settings_pane_visit_again_header": "Bisitahin Muli",
  "settings_pane_visit_again_body": "Ipapakita sa iyo ng Firefox ang mga bahagi ng iyong kasaysayan ng pagba-browse na maaaring gusto mong matandaan o makabalik.",
  "settings_pane_highlights_header": "Mga highlight",
  "settings_pane_highlights_body2": "Hanapin ang iyong daan pabalik sa mga kagiliw-giliw na bagay na kamakailan mong binisita o na-bookmark.",
  "settings_pane_highlights_options_bookmarks": "Mga bookmark",
  "settings_pane_highlights_options_visited": "Mga binisitang site",
  "settings_pane_snippets_header": "Mga snippet",
  "settings_pane_snippets_body": "Magbasa ng maikli at matamis na mga update mula sa Mozilla tungkol sa Firefox, kultura sa internet, at paminsan-minsang random na meme.",
  "settings_pane_done_button": "Tapos",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "edit_topsites_button_text": "I-edit",
  "edit_topsites_button_label": "I-customize ang iyong Tuktok na mga seksyon ng Sites",
  "edit_topsites_showmore_button": "Magpakita ng higit pa",
  "edit_topsites_showless_button": "Magpakita ng mas kaunti",
  "edit_topsites_done_button": "Tapos",
  "edit_topsites_pin_button": "I-pin sa site na ito",
  "edit_topsites_unpin_button": "I-unpin ang site na ito",
  "edit_topsites_edit_button": "I-edit ang site na ito",
  "edit_topsites_dismiss_button": "I-dismiss sa site na ito",
  "edit_topsites_add_button": "Idagdag",
  "topsites_form_add_header": "Bagong nangungunang site",
  "topsites_form_edit_header": "I-edit ang nangungunang site",
  "topsites_form_title_placeholder": "Magpasok ng isang pamagat",
  "topsites_form_url_placeholder": "I-type o i-paste ang URL",
  "topsites_form_add_button": "Idagdag",
  "topsites_form_save_button": "I-save",
  "topsites_form_cancel_button": "Kanselahin",
  "topsites_form_url_validation": "Wastong URL ang kinakailangan",
  "pocket_read_more": "Tanyag na mga paksa:",
  "pocket_read_even_more": "Tignan ang higit pang mga kuwento",
  "pocket_feedback_header": "Ang pinakamahusay sa web, na gawa ng higit sa 25 milyong tao.",
  "pocket_description": "Tuklasin ang mataas na kalidad na nilalaman na maaari mong makaligtaan, sa tulong ng Pocket, ay bahagi na ngayon ng Mozilla.",
  "highlights_empty_state": "Magsimulang mag-browse, at ipapakita namin ang ilan sa mga magagandang artikulo, video, at iba pang mga pahina na kamakailan mong binisita o na-bookmark dito.",
  "topstories_empty_state": "Nakahabol ka na. Bumalik sa ibang pagkakataon para sa higit pang mga nangungunang kuwento mula sa {provider}. Hindi makapaghintay? Pumili ng isang tanyag na paksa upang makahanap ng higit pang mahusay na mga kuwento mula sa buong web.",
  "manual_migration_explanation2": "Subukan ang Firefox gamit ang mga bookmark, kasaysayan at mga password mula sa isa pang browser.",
  "manual_migration_cancel_button": "Salamat na lang",
  "manual_migration_import_button": "Angkatin Ngayon"
};

==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/tl/activity-stream-strings.js <==
// Note - this is a generated tl file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Bagong Tab",
  "header_top_sites": "Tuktok na mga Site",
  "header_highlights": "Naka-highlight",
  "header_recommended_by": "Inirekomenda ni {provider}",
  "context_menu_button_sr": "Buksan ang menu ng konteksto para sa {title}",
  "section_context_menu_button_sr": "Buksan ang menu ng konteksto ng seksyon",
  "type_label_visited": "Binisita",
  "type_label_bookmarked": "Bookmarked",
  "type_label_recommended": "Nagte-trend",
  "type_label_pocket": "I-save sa Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Bookmark",
  "menu_action_remove_bookmark": "Alisin ang Bookmark",
  "menu_action_open_new_window": "Buksan sa isang Bagong Window",
  "menu_action_open_private_window": "Buksan sa isang Pribadong Bago na Window",
  "menu_action_dismiss": "Paalisin",
  "menu_action_delete": "Tanggalin mula History",
  "menu_action_pin": "I-pin",
  "menu_action_unpin": "I-unpin",
  "confirm_history_delete_p1": "Sigurado ka bang gusto mong tanggalin ang bawat pagkakataon ng pahinang ito mula sa iyong kasaysayan?",
  "confirm_history_delete_notice_p2": "Ang aksyon na ito ay hindi na mababawi.",
  "menu_action_save_to_pocket": "I-save sa Pocket",
  "menu_action_delete_pocket": "I-delete sa Pocket",
  "menu_action_archive_pocket": "Mag-archive sa Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Hanapin",
  "search_header": "{search_engine_name} Hanapin",
  "search_web_placeholder": "Hanapin sa Web",
  "section_disclaimer_topstories": "Ang pinaka-kagiliw-giliw na mga kwento sa web, pinili batay sa kung ano ang iyong nabasa. Mula sa Pocket, bahagi na ngayon ng Mozilla.",
  "section_disclaimer_topstories_linktext": "Alamin kung paano ito gumagana.",
  "section_disclaimer_topstories_buttontext": "Sige, nakuha ko",
  "prefs_home_header": "Nilalaman ng Home ng Firefox",
  "prefs_home_description": "Piliin kung anong nilalaman ang gusto mo sa iyong screen ng Home ng Firefox.",
  "prefs_section_rows_option": "{num} hilera;{num} mga hilera",
  "prefs_search_header": "Paghahanap sa Web",
  "prefs_topsites_description": "Ang mga site na iyong pinupuntahan",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Matuto ng higit pa",
  "prefs_highlights_description": "Ang isang seleksyon ng mga site na iyong nai-save o binisita",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Mga Update mula sa Mozilla at Firefox",
  "settings_pane_button_label": "I-customize ang iyong pahina ng Bagong Tab",
  "settings_pane_topsites_header": "Tuktok na mga Site",
  "settings_pane_highlights_header": "Mga highlight",
  "settings_pane_highlights_options_bookmarks": "Mga bookmark",
  "settings_pane_snippets_header": "Mga snippet",
  "edit_topsites_button_text": "I-edit",
  "edit_topsites_edit_button": "I-edit ang site na ito",
  "topsites_form_add_header": "Bagong nangungunang site",
  "topsites_form_edit_header": "I-edit ang nangungunang site",
  "topsites_form_title_label": "Pamagat",
  "topsites_form_title_placeholder": "Magpasok ng isang pamagat",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL ng Custom na Larawan",
  "topsites_form_url_placeholder": "I-type o i-paste ang URL",
  "topsites_form_use_image_link": "Gamitin ang URL custom na larawan...",
  "topsites_form_preview_button": "I-preview",
  "topsites_form_add_button": "Idagdag",
  "topsites_form_save_button": "I-save",
  "topsites_form_cancel_button": "Kanselahin",
  "topsites_form_url_validation": "Wastong URL ang kinakailangan",
  "topsites_form_image_validation": "Nabigo ang pag-load ng larawan. Subukan ang ibang URL.",
  "pocket_read_more": "Tanyag na mga paksa:",
  "pocket_read_even_more": "Tignan ang higit pang mga kuwento",
  "highlights_empty_state": "Magsimulang mag-browse, at ipapakita namin ang ilan sa mga magagandang artikulo, video, at iba pang mga pahina na kamakailan mong binisita o na-bookmark dito.",
  "topstories_empty_state": "Nakahabol ka na. Bumalik sa ibang pagkakataon para sa higit pang mga nangungunang kuwento mula sa {provider}. Hindi makapaghintay? Pumili ng isang tanyag na paksa upang makahanap ng higit pang mahusay na mga kuwento mula sa buong web.",
  "manual_migration_explanation2": "Subukan ang Firefox gamit ang mga bookmark, kasaysayan at mga password mula sa isa pang browser.",
  "manual_migration_cancel_button": "Salamat na lang",
  "manual_migration_import_button": "Angkatin Ngayon",
  "error_fallback_default_info": "Oops, may naganap na mali sa paglo-load ng nilalamang ito.",
  "error_fallback_default_refresh_suggestion": "I-refresh ang pahina upang subukang muli.",
  "section_menu_action_remove_section": "Alisin ang Seksyon",
  "section_menu_action_collapse_section": "I-collapse ang Seksyon",
  "section_menu_action_expand_section": "Palawakin ang Seksyon",
  "section_menu_action_manage_section": "Pamahalaan ang Seksyon",
  "section_menu_action_add_topsite": "Magdagdag ng Nangungunang Site",
  "section_menu_action_move_up": "Ilipat Up",
  "section_menu_action_move_down": "Ilipat sa Baba",
  "section_menu_action_privacy_notice": "Paunawa sa Privacy",
  "default_label_loading": "Pagkarga…",
  "header_stories": "Nangunguna na mga Kwento",
  "header_visit_again": "Bisitahin Muli",
  "header_bookmarks": "Kamakailang mga Bookmark",
  "header_bookmarks_placeholder": "Wala kang anumang mga bookmark.",
  "header_stories_from": "mula sa",
  "type_label_synced": "Naka-sync mula sa ibang kagamitan",
  "type_label_open": "Bukas",
  "type_label_topic": "Topiko",
  "type_label_now": "Ngayon",
  "menu_action_copy_address": "Kopyahin ang Address",
  "menu_action_email_link": "Email Link…",
  "search_for_something_with": "Maghanap ng mga {search_term} na may:",
  "search_settings": "Baguhin ang mga Setting ng Paghahanap",
  "section_info_option": "Impormasyon",
  "section_info_send_feedback": "Magbigay ng Feedback",
  "section_info_privacy_notice": "Abiso sa Privacy",
  "welcome_title": "Maligayang pagdating sa bagong tab",
  "welcome_body": "Firefox ay gagamit ng puwang upang ipakita ang iyong mga pinaka-kaugnay na bookmark, artikulo, video, at mga pahina ng kamakailan na iyong binisita, kaya maaari kang bumalik sa mga ito ng madali.",
  "welcome_label": "Ang pagkilala sa iyong Highlights",
  "time_label_less_than_minute": "<1m",
  "time_label_minute": "{number}m",
  "time_label_hour": "{number}h",
  "time_label_day": "{number}d",
  "prefs_restore_defaults_button": "Ibalik sa dating ayos",
  "prefs_topstories_description": "Maaaring makaligtaan ang mataas na kalidad na nilalaman",
  "prefs_topstories_show_sponsored_label": "{provider} Mga Na-sponsor na Kwento",
  "settings_pane_header": "Bagong Kagustuhan na Tab",
  "settings_pane_body2": "Piliin kung ano ang gusto mong makita sa pahinang ito.",
  "settings_pane_search_header": "Paghahanap",
  "settings_pane_search_body": "Hanapin sa Web mula sa iyong bagong tab.",
  "settings_pane_topsites_body": "Ma-access ang mga website na karamihang binibisita.",
  "settings_pane_topsites_options_showmore": "Ipakita ang dalawang mga hanay",
  "settings_pane_bookmarks_header": "Kamakailang mga Bookmark",
  "settings_pane_bookmarks_body": "Ang iyong mga bagong gawang bookmark ay nsa isang madaling gamiting lokasyon.",
  "settings_pane_visit_again_header": "Bisitahin Muli",
  "settings_pane_visit_again_body": "Ipapakita sa iyo ng Firefox ang mga bahagi ng iyong kasaysayan ng pagba-browse na maaaring gusto mong matandaan o makabalik.",
  "settings_pane_highlights_body2": "Hanapin ang iyong daan pabalik sa mga kagiliw-giliw na bagay na kamakailan mong binisita o na-bookmark.",
  "settings_pane_highlights_options_visited": "Mga binisitang site",
  "settings_pane_snippets_body": "Magbasa ng maikli at matamis na mga update mula sa Mozilla tungkol sa Firefox, kultura sa internet, at paminsan-minsang random na meme.",
  "settings_pane_done_button": "Tapos",
  "settings_pane_topstories_options_sponsored": "Ipakita ang Mga Na-sponsor na Kuwento",
  "edit_topsites_button_label": "I-customize ang iyong Tuktok na mga seksyon ng Sites",
  "edit_topsites_showmore_button": "Magpakita ng higit pa",
  "edit_topsites_showless_button": "Magpakita ng mas kaunti",
  "edit_topsites_done_button": "Tapos",
  "edit_topsites_pin_button": "I-pin sa site na ito",
  "edit_topsites_unpin_button": "I-unpin ang site na ito",
  "edit_topsites_dismiss_button": "I-dismiss sa site na ito",
  "edit_topsites_add_button": "Idagdag",
  "pocket_feedback_header": "Ang pinakamahusay sa web, na gawa ng higit sa 25 milyong tao.",
  "pocket_description": "Tuklasin ang mataas na kalidad na nilalaman na maaari mong makaligtaan, sa tulong ng Pocket, ay bahagi na ngayon ng Mozilla."
};
